@@ -5,4 +5,6 @@ from zenutils.sixutils import *
 
 from .base import *
 from .app import DaemonApplication
-from .app import SimpleRpcServer
\ No newline at end of file
+from .app import SimpleXmlRpcServer
+from .app import SimpleXmlRpcServerEngine
+from .app import SimpleRpcApplication
\ No newline at end of file
