@@ -5,8 +5,10 @@ from zenutils.sixutils import *
 
 __all__ = [
     "DaemonApplication",
+    "ServerEngineBase",
     "SimpleXmlRpcServer",
-    "SimpleRpcServer",
+    "SimpleXmlRpcServerEngine",
+    "SimpleRpcApplication",
     "simple_rpcd_controller",
 ]
 
@@ -16,6 +18,7 @@ import time
 import signal
 import logging
 from pprint import pprint
+
 try:
     from socketserver import ThreadingMixIn
     from xmlrpc.server import SimpleXMLRPCServer
@@ -25,7 +28,6 @@ except ImportError:
     from SimpleXMLRPCServer import SimpleXMLRPCServer
     from SimpleXMLRPCServer import SimpleXMLRPCRequestHandler
 
-
 import click
 import yaml
 import magic_import
@@ -203,23 +205,31 @@ class DaemonApplication(object):
 
 
 class SimpleXmlRpcServer(ThreadingMixIn, SimpleXMLRPCServer):
-
-    def __init__(self, config):
-        self.config = config
-        xmlrpc_server_init_args = (
-            (self.config.select("server.listen"), self.config.select("server.port")),
-        )
-        xmlrpc_server_init_kwargs = {
-            "requestHandler": SimpleXMLRPCRequestHandler,
-            "allow_none": self.config.select("server.allow_none", True),
-            "encoding": self.config.select("server.encoding", "utf-8"),
-        }
-        SimpleXMLRPCServer.__init__(self, *xmlrpc_server_init_args, **xmlrpc_server_init_kwargs)
-        self.register_introspection_functions()
-        self.register_multicall_functions()
+    pass
 
 
-class SimpleRpcServer(DaemonApplication):
+class SimpleXmlRpcServerEngine(serviceutils.ServerEngineBase):
+
+    def make_core_server(self):
+        listen = self.config.select("server.listen")
+        port = self.config.select("server.port")
+        allow_none = self.config.select("server.allow_none", True)
+        encoding = self.config.select("server.encoding", "utf-8")
+        core_server = SimpleXmlRpcServer(
+            (listen, port),
+            requestHandler=SimpleXMLRPCRequestHandler,
+            allow_none=allow_none,
+            encoding=encoding,
+            )
+        core_server.register_introspection_functions()
+        core_server.register_multicall_functions()
+        return core_server
+    
+    def register_function(self, method, name):
+        return self.core_server.register_function(function=method, name=name)
+
+
+class SimpleRpcApplication(DaemonApplication):
 
     def get_default_server_listen(self):
         return getattr(self, "default_server_listen", "0.0.0.0")
@@ -227,15 +237,15 @@ class SimpleRpcServer(DaemonApplication):
     def get_default_listen_port(self):
         return getattr(self, "default_server_port", 8381)
 
-    def get_default_server_class(self):
-        return getattr(self, "default_server_class", "daemon_application.app.SimpleXmlRpcServer")
+    def get_default_server_engine_class(self):
+        return getattr(self, "default_server_engine_class", "daemon_application.app.SimpleXmlRpcServerEngine")
 
     def get_default_config(self):
         default_config = {
             "server": {
                 "listen": self.get_default_server_listen(),
                 "port": self.get_default_listen_port(),
-                "class": self.get_default_server_class(),
+                "engine_class": self.get_default_server_engine_class(),
             }
         }
         more_default_config = DaemonApplication.get_default_config(self)
@@ -245,18 +255,16 @@ class SimpleRpcServer(DaemonApplication):
     def main(self):
         logutils.setup(**self.config)
         # make server
-        server_class = self.config.get("class", self.get_default_server_class())
-        ServerClass = magic_import.import_from_string(server_class)
-        if not ServerClass:
-            _logger.fatal("SimpleRpcServer.make_server failed: server class {server_class} not found...".format(server_class=server_class))
+        server_engine_class = self.config.get("server.engine_class", self.get_default_server_engine_class())
+        ServerEngineClass = magic_import.import_from_string(server_engine_class)
+        if not ServerEngineClass:
+            _logger.fatal("SimpleRpcServer.make_server failed: server engine class {server_engine_class} not found...".format(server_engine_class=server_engine_class))
             sys.exit(1)
-        self.server = ServerClass(self.config)
-        # load services
-        self.services = {}
+        self.server_engine = ServerEngineClass(self.config)
+
         # register debug service
         if self.config.select("enable-debug-service", True):
-            self.debug_service = serviceutils.DebugService(self.config)
-            self.debug_service.register_to(self.server)
+            serviceutils.DebugService(self.config).register_to(self.server_engine)
         # load more services
         service_configs = self.config.select("services", [])
         for service_config in service_configs:
@@ -280,20 +288,20 @@ class SimpleRpcServer(DaemonApplication):
             _logger.info(msg)
             service_args = service_config.select("args", [])
             service_kwargs = service_config.select("kwargs", {})
-            self.services[service_class_name] = Service(self.config, *service_args, **service_kwargs)
-            self.services[service_class_name].register_to(self.server)
+            Service(self.config, *service_args, **service_kwargs).register_to(self.server_engine)
         # start server
         try:
             _logger.info("Starting server on {listen}:{port}...".format(
                 listen=self.config.select("server.listen", self.get_default_server_listen()),
                 port=self.config.select("server.port", self.get_default_listen_port()),
                 ))
-            self.server.serve_forever()
+            self.server_engine.serve_forever()
         except KeyboardInterrupt:
             _logger.info("Got KeyboardInterrupt signal, stopping the service...")
 
 
-simple_rpcd_controller = SimpleRpcServer().get_controller()
+simple_rpcd_controller = SimpleRpcApplication().get_controller()
+
 
 if __name__ == "__main__":
     simple_rpcd_controller()
