@@ -13,7 +13,7 @@ class HelloApplication(DaemonApplication):
         options = [
             click.option("-m", "--message", default="hello")
         ]
-        return options + super().get_main_options()
+        return options + DaemonApplication.get_main_options(self)
 
     def main(self):
         while True:
